#
# spec file for package lightspark
#
# Copyright (c) 2020 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%bcond_without ffmpeg
%bcond_with    rtmp
Name:           lightspark
Version:        0.8.3
Release:        pm151.14.3
Summary:        Flash player implementation
License:        LGPL-3.0-or-later
Group:          Productivity/Multimedia/Other
URL:            https://lightspark.github.io/
Source0:        %{name}-%{version}.tar.xz
BuildRequires:  cmake
BuildRequires:  desktop-file-utils
BuildRequires:  gcc-c++
BuildRequires:  gettext-tools
BuildRequires:  hicolor-icon-theme
BuildRequires:  llvm-devel >= 2.8
BuildRequires:  nasm
BuildRequires:  pkgconfig
BuildRequires:  pkgconfig(SDL2_mixer)
BuildRequires:  pkgconfig(cairo)
BuildRequires:  pkgconfig(gdk-2.0)
BuildRequires:  pkgconfig(gl)
BuildRequires:  pkgconfig(glew)
BuildRequires:  pkgconfig(glib-2.0)
BuildRequires:  pkgconfig(gmodule-2.0)
BuildRequires:  pkgconfig(gthread-2.0)
BuildRequires:  pkgconfig(libcurl)
BuildRequires:  pkgconfig(libjpeg)
BuildRequires:  pkgconfig(liblzma)
BuildRequires:  pkgconfig(libpcre)
BuildRequires:  pkgconfig(libpng)
BuildRequires:  pkgconfig(libxml++-2.6) >= 2.33.1
BuildRequires:  pkgconfig(ncurses)
BuildRequires:  pkgconfig(pango)
BuildRequires:  pkgconfig(pangocairo)
BuildRequires:  pkgconfig(sdl2)
BuildRequires:  pkgconfig(x11)
BuildRequires:  pkgconfig(zlib)
Requires(post): hicolor-icon-theme
Requires(post): update-desktop-files
Requires(postun): hicolor-icon-theme
Requires(postun): update-desktop-files
Recommends:     %{_bindir}/gnash
Recommends:     %{name}-lang
ExclusiveArch:  %{ix86} x86_64
%if 0%{?suse_version} >= 1500
BuildRequires:  libboost_filesystem-devel
BuildRequires:  libboost_system-devel
%else
BuildRequires:  boost-devel
%endif
%if %{with librtmp}
BuildRequires:  pkgconfig(libcrypto)
BuildRequires:  pkgconfig(librtmp)
BuildRequires:  pkgconfig(libssl)
%endif
%if %{with ffmpeg}
BuildRequires:  pkgconfig(libavcodec)
BuildRequires:  pkgconfig(libavformat)
BuildRequires:  pkgconfig(libavresample)
BuildRequires:  pkgconfig(libavutil)
%endif

%description
Lightspark is an Flash player implementation for playing files in SWF
format. Lightspark can run as a web browser plugin or as a standalone
application.

Lightspark supports SWF files written on the newest version of the
ActionScript language, ActionScript 3.0, which was introduced at the
same time as Flash Player 9.

%lang_package

%package plugin
Summary:        NPAPI plugin for lightspark
Group:          Productivity/Multimedia/Other
Requires:       %{name} = %{version}
Enhances:       browser(npapi)
Conflicts:      flash-player
Conflicts:      gnash-browser-plugin

%description plugin
NPAPI plugin for lightspark.

%prep
%autosetup
rm -f build

%build
%cmake \
  -DPLUGIN_DIRECTORY=%{_libdir}/browser-plugins \
  -DPPAPI_PLUGIN_DIRECTORY=%{_libdir}/browser-plugins \
  -DENABLE_LIBAVCODEC=%{?with_ffmpeg:YES}%{!?with_ffmpeg:NO} \
  -DENABLE_RTMP=%{?with_rtmp:YES}%{!?with_rtmp:NO} \
  %ifarch x86_64 || %{ix86}
  -DENABLE_SSE2=true \
  %endif
  -Wno-dev
%cmake_build

%install
%cmake_install
%find_lang %{name}
rm -f %{buildroot}%{_libdir}/%{name}/lib%{name}.so
mv %{buildroot}%{_libdir}/%{name}/* \
  %{buildroot}%{_libdir}/
# Not in hicolor theme (lp#1000840)
rm -rf %{buildroot}%{_datadir}/icons/hicolor/20x20

%post -p /sbin/ldconfig
%postun -p /sbin/ldconfig

%files
%license COPYING.LESSER
%doc ChangeLog
%config(noreplace) %{_sysconfdir}/xdg/lightspark.conf
%attr(0755,root,root) %{_bindir}/lightspark
%{_datadir}/applications/lightspark.desktop
%{_datadir}/icons/hicolor/*/*/*
%{_mandir}/man1/lightspark.1*
%{_libdir}/lib%{name}.so*

%files lang -f %{name}.lang

%files plugin
%{_libdir}/browser-plugins/*.so
%{_libdir}/browser-plugins/manifest.json

%changelog
* Sat Sep  5 2020 aloisio@gmx.com
- Update to version 0.8.3:
  * new version 0.8.3
  * fix callproperty optimization
  * Added Orientation3D class
  * [StaticText] use same hitTestImpl as in TextField
  * ensure that "complete" event is sended for root movieclip fixes #520
  * ensure arguments are converted to int in abc_getPropertyInteger* calls fixes #519
  * optimize inclocal_i/declocal_i
  * [PlaceObject2Tag] reduce number of calls to getUniqueStringId()
  * small speedup when writing to ByteArray
  * fix several comparison optimizations
  * fix setting next frame from Actionscript
  * fix parsing of OBJECT/EMBED parameters
  * small performance improvements
  * make AudioStream class public fixes #496
  * speedup generation of string ids on startup fixes #516
  * fix increment_i/decrement_i optimization
  * fix construction of RootMovieClip from loaded swf fixes #515
  * fix ifnge optimization
  * fix optimization of static method calls
  * fix detection of unreachable code
  * avoid coercing function result if unneccessary
  * script for uninstalling
  * optimize ifnge opcode
  * fix callproperty optimization
  * fix previous commit
  * small performance improvement
  * avoid creating new call_context when not in recursive function call
  * small performance improvements
  * Fix indentations in the last 4 commits
  * Added JPEGEncoderOptions
  * Added JPEGXREncoderOptions
  * Added PNGEncoderOptions
  * Added MicrophoneEnhancedOptions
  * several small performance improvements
  * fix building in debug mode
  * fix several warnings fixes #512
  * fix advancing frame during parsing
  * [Texture] fix uploadFromBitmapData
  * fix loading of Bitmaps from Loader
  * make windows executable work on Windows7 fixes #454
  * [ColorTransform] fix applyTransformation for Bitmaps
  * [ABCVm] fix coercearguments detection
  * [ABCVm] fix preloading of finddef opcode
  * Added ID3Info
  * [ABCVm] put (optimized) methods in separate files
  * [BitmapContainer] fix handling of PNGs without alpha
  * [ABCVm] use new typestack to avoid argument coercion in callProperty
  * [Global] ensure that script is run when first accessed from setter
  * ensure framescript for frame 0 is executed in root movie
  * keep track of the type of the arguments on stack during preloadFunction currently only used for get/setPropertyInteger optimization
  * Added AVTagData
  * Added ColorCorrectionSupport
  * stop sound streaming if MovieClip is stopped fixes second part of #509
  * fix possible crash fixes first part of #509
  * [URLRequest] allow Authorization header contrary to specs, it seems to be allowed in newer flash player versions see https://helpx.adobe.com/flash-player/kb/actionscript-error-send- action-contains.html
  * [RegExp] fix match
  * only execute ScriptLimitsTag on main clip fixes #508
  * [flash.geom] implement copyFrom for Point, Rectangle and Vector3D
  * fix get/setPropertyInteger optimization fixes #507
  * optimize get/setProperty with Integer parameter
  * fix RootMovieClip afterConstruction fixes #505 and #506
  * [AVM1] implement _rotation getter/setter
  * [AVM1] don't execute scripts directly in AttachMovie fixes #504
  * fix putting root movie clip on stage fixes #500 and #503
  * fix calling of AVM1 constructors fixes #499
  * implement support for AdditionalDataTag in PlaceObject2Tag
  * [AVM1] rework DoInitAction tag handling
  * [AVM1] fix ActionWith handling fixes #490
  * fix RootMovieClip construction (again...)
  * Added more constants
  * fix setting super class
  * fix construction of RootMovieClip for AVM1
  * [ABCVm] fix optimization of getlex for constants
  * fix construction of RootMovieClip
  * fix SoundStreamBlockTag::decodeSoundBlock partially fixes #489
  * prefer inherited classes with same name over builtin classes
  * [DisplayObject] fix refcounting for getRoot fixes #492 and #493
  * fix initializing of embedded swf fixes #488
  * [AVM1] fix DoInitActionTag handling fixes #487
  * [PlaceObject2Tag] fix reusing removed legacy children fixes #484
  * ensure main object is added to stage after it is completely constructed fixes #494
  * add forgotten patch
  * [AVM1] add caller/callee to arguments array
  * fix usage of additional AdditionalDataTag in AVM1 obfuscation fixes #486 and #491
  * fix reading of additionalDataTag
  * [DisplayObjectContainer] fix handling of mouseChildren for hittest fixes #485
  * fix reading GRADIENTGLOWFILTER
  * [DisplayObject] fix setOnStage
  * fix referencecounting when executing event listeners fixes #483
  * [ABCVm] optimize getlex for constants
  * [Vector] speedup coerce
  * [ByteArray] fix handling of invalid UTF8 in toString
  * partially revert "ensure that classes are defined as soon as possible" this fixes several regressed tamarin tests
  * fix computation of bounds rect
  * [ABCVm] fix skipping of unreachable code fixes #467
  * Fixed line indentatons
  * Added more flash.globalization contast values
  * [AVM1] execute scripts for MovieClips not generated from timeline
  * ensure that classes are defined as soon as possible fixes #479
  * Fixed last operation values in some flash.globalization classes
  * Split classes in flashglobalization.* to other files
  * [ABCVm] fix optimizing of skippable opcodes
  * Added StringTools class
  * [ByteArray] speedup toString
  * [AVM1] fix ContextMenu handling fixes #478
  * [AVM1] fix ActionWith handling fixes #477
  * [AVM1] fix handling of jumps beyond actionlist size
  * [AVM1] AVM1 allows setting contextMenu to a DisplayObject
  * fix handling of FrameLabelTag
  * [AVM1] check for class variables first in AVM1GetVariable
  * fix possible crash
  * rework AVM1 interpreter to avoid problems with obfuscation fixes #459
  * travis.yaml: Add Debug Build
  * implement flash.filters.BitmapFilterType fixes #472
  * [BitmapData] add stub for paletteMap fixes #473
  * [AVM1] only execute clipactions if dispatcher is correct fixes #471
  * [PlaceObject2Tag] fix placing of BitmapData tags
  * fix parsing of PlaceObject3Tag
  * fix refcounting for global variables
  * implement applying of ColorTransform to bitmap fill style
  * [MovieClip] fix AdvanceFrame if clip has not yet finished loading fixes #456
  * fix clang builds
  * add 32bit windows version to travis
  * [DisplayObject] fix possible crash in getVariableBindingValue fixes #466
  * [AVM1] fix attachMovieClip
  * [Function] fix setting of returnType
  * [AVM1] fix getting variables with dot
  * fix several refcounting bugs fixes #458
  * add new command line argument to ignore unhandled exceptions fixes #457
  * [SyntheticFunction] fix isEqual
  * Undo unintended change
  * Oops
  * Check before doing anything
  * Refactor to do help before the other stuff
  * Add extra checks
  * Do debug and release builds in different dirs
  * Keep original build instructions
  * [MovieClip] wait until the frame is loaded in gotoAndPlay/Stop
  * fix html parsing of <br> tags
  * fix binding of classes that are initialized in a frame not yet loaded fixes 447
  * Clarify running of build-script a bit
  * Use build script in .travis.yml
  * Refactor handling of input and add help message
  * [DisplayObjectContainer] fix possible crash during declareFrame
  * [PlaceObject3Tag] implement support for PlaceFlagHasVisible
  * Update README.md
  * Create build
  * fix generating of images without alpha
  * [ABCVm] optimize setProperty if no operands are available
  * small performance improvement
  * Replaced uint to uint32_t in currencyformatter.h
  * Undo merge issues
  * Removed added line in DateTimeStyle
  * Made changes to CurrencyFormatter format method
  * Logic error fixes
  * Dead code elimination
  * Fix dumb typo
  * Updates to README.md
  * add stubs for classes GameInput/GameInputDevice/GameInputEvent
  * don't play sound when skipping frames from actionscript fixes #450
  * partially implement flash.globalization.NumberFormatter fixes #449
  * [RootMovieClip] turn dictionary into an unordered_map this significantly speeds up parsing of big swf files
  * [AVM1] all parameters for MovieClip.startDrag are optional fixes #455
  * fix some XML issues fixes #452
  * fix image decoding
  * [LoaderThread] ensure content is set when loading from ByteArray fixes #451
  * Made more progress in CurrencyFormatter
  * [AVM1] implement _url for ActionGetProperty
  * [AVM1] add stub for MovieClip.loadMovie
  * don't allocate sounddata on stack as it may be quite large
  * [AVM1] fix setting of prototype fixes #446
  * implement ContextMenus the builtin commands are not doing anything yet, but items added by the developer are handled properly fixes #443
  * Initial implementation of CurrencyFormatter Flash API class
  * [DisplayObject] fix possible crash in swapDepths
  * [AVM1] always search case-insensitive for AVM1 functions
  * [PlaceObject2Tag] remove unneeded workaround for AVM1
  * throw exception when trying to delete function from sealed object
  * fix creating instance of ASObject
  * [Date] handle constructor with infinity as parameter
  * add more tests to blacklist adobe player fails at them in the same way lightspark does
  * [Number] use adobes avmplus code for converting numbers to strings taken from https://github.com/adobe/avmplus
  * [PlaceObject2Tag] only call constructionComplete in AVM1
  * don't advance frame during executing of framescript fixes #444
  * fix constructing MovieClips from Tags
  * [BitmapData] implement hitTest with Bitmap/BitmapData as secondObject
  * fix compilation with minGW, 3rd try...
  * fix compilation with minGW, 2nd try
  * fix compilation on minGW
  * [Context3D] implement setColorMask and setScissorRectangle
  * [ABCVm] fix optimization of lf32/lf64 opcodes
  * [Texture] patially implement uploadCompressedTextureFromByteArray
  * [Texture] implement uploadFromByteArray
  * [CubeTexture] implement uploadFromBitmapData
  * fix order of construction for DisplayObjects fixes #441
  * [avmplus] partially implement describeTypeJSON
  * fix stage3d rendering
  * [ByteArray] remove nullbytes at end of result in readMultiByte
  * handle identical name for protected namespace in different loaded swfs
  * add stubs for several methods in flash.sampler package shoud fix #437
  * fix several issues when loading additional swf files
  * better handling of wrong parameter in getlocal opcode fixes #439
  * implement flash.events.ThrottleEvent
  * fix describeType for object instances
  * set traitsInitialized for tags that are not binded to a class
  * fix warning
  * fix skipping of jump tags fixes #429
  * fix screenshot generation fixes #430
  * fix rendering of error messages when resizing fixes #432
  * Update SWF Support section
  * switch to Ctrl+S as shortcut for screenshot generation
  * fix stupid memory leak on screenshot generation should fix #427
  * don't throw exception if id is not found on dictionary
  * [AVM1] reuse soundchannel from DefineSoundTag in attachSound should fix #425
  * fix StartSoundTag if DefineSoundTag is attached to a sound object fixes #422
  * implement ability to create screenshot with keyboard shortcut Ctrl+o fixes #245
  * fix handling of dynamic functions fixes #424
  * [HtmlTextParser] handle &nbsp;
  * fix possible crash
  * fix possible crash when plotting profile data fixes #420
  * ensure that rendering is not done during AdvanceFrameEvent fixes #423
  * [TokenContainer] fix colorTransformation handling
  * [AVM1] implement Object.registerClass
  * [AVM1] store member variables case sensitive
  * [AVM1] implement ActionCallMethod with empty name
  * [AVM1] add TextFormat class
  * [PlaceObject2Tag] handle ClipEventConstruct and ClipEventInitialize
  * [AVM1] fix Object.addProperty fixes #416
  * [AVM1] implement ActionInstanceOf and ActionExtends
  * fix warnings
  * fix handling of reused DisplayObjects fixes #421
  * fix compilation on Ubuntu 16.04
  * fix event handling when in fullscreen mode on Firefox fixes #419
  * [DefineSoundTag] detect sample rate regardless of value provided
  * fix creation of cache directory
  * [AVM1Sound] store position when stopping sound fixes #418
  * [TextField] prefer embedded font from loaded swf fixes #417
  * remove boost dependency
  * add workaround for SoundChannel.position to match adobes behaviour fixes #398
  * fix variable binding for textfields and properly handle case sensitivity for Stage.DisplayState fixes #415
  * [RenderThread] dont't do any rendering if nothing has changed fixes #401
  * [SimpleButton] ensure reflectState() is called on construction
  * [FontTag] ignore spaces when checking for available glyphs fixes #410
  * more readable keyboard shortcut explanations
  * fix possible crash in firefox plugin.cpp fixes #413
  * [AVM1] don't throw exception if setting display state is not allowed
  * [Stage] implement softKeyboardRect as stub
  * fix compilation with profiling
  * [IntervalRunner] fix refcounting
  * fix resizing
  * [EventDispatcher] properly initialze forcedTarget
  * ensure that traits are initialized for movies loaded from actionscript
  * handle asAtom isLess for (U)Integer ASObjects
  * [AVM1] fix handling of function parameters as locals (2nd try) fixes #411
  * Update README.md
  * fix loading of embedded fonts fixes #407
  * add Keyboard shortcut (Ctrl+f) for switching to/from fullscreen view fixes #404
  * fix URL for flex download fixes #400
  * reset state of reused legacy objects fixes #402
  * ensure tag instances not binded to a class are marked as constructed fixes #403
  * [AVM1] fix handling of function parameters as locals
  * [AVM1] implement Color class
  * Fix build with boost 1.72.0.
  * [AVM1] handle case insensivity in ActionGetMember
  * [AVM1] don't crash if attaching a movie fails
  * [AVM1] properly store AVM1Functions as variable
  * [AVM1] implement tag ActionStringExtract
  * [AVM1] add System.security class
  * [AVM1] implement getSWFVersion
  * [AVM1] allow zero parameters in getBounds fixes #399
  * [AVM1] implement global "_level0" property
  * Rework "Reporting Bugs"
  * set audiostream starting time based on first mixing callback
  * create soundchannel also if the sound is not connected to a clip
  * ensure _named_ displayobjects are reused when re-added to timeline this seems to be how adobe handles it fixes #397
  * [AVM1] fix mouse click handling
  * [TextField] handle negative values when setting width/height
  * fix some refcounting issues
  * fix some warnings on llvm
  * [AVM1] implement video streaming
  * [AVM1] make function names case insensitive
  * [AVM1] fix xml loading/parsing
  * [AVM1] ensure that handler for onPress is not called twice
  * [AVM1] implement setInterval with 3+ arguments
  * [AVM1] implement MovieClip.getInstanceAtDepth
  * ensure init/complete events are sended after image is loaded
  * [AVM1] fix Function.apply/call
  * [AVM1] implement XML loading
  * only render if all flushed drawjobs are done, 2nd try fixes #396
  * only render if all drawjobs that are flushed in one step are done fixes the remaining parts of #393
  * [SoundChannel] fix stopping fixes #395
  * fix bitmap rendering on resized window fixes #394
  * [SoundChannel] ensure that position is correctly reported after the whole sound is loaded fixes part 3 of #393
  * fix rendering when resizing window fixes #378 and #392
  * fix mouse down events for AVM1 fixes #388
  * [SimpleButton] implement getTagID fixes #389
  * ensure that "complete" event is handled after all "progress" events fixes #390
  * implement support for fullscreen mode fixes #387
  * fix possible deadlocks on exit fixes #386
  * fix handling of hasChanged flag in invalidation fixes #384
  * [CairoRenderer] ensure pixelbuffer is always large enough fixes #385
  * [ABCVm] fix checklocalresult (again...)
  * [Sound] properly handle stopping and (re)starting of sound fixes #383
  * [AVM1] fix MovieClipLoader fixes #379
  * improve progressEvent handling
  * [AVM1] fix ActionWith handling fixes #382
  * implement undocumented NameCharacter tag
  * [ABCVm] fix checkforlocalresult
  * fix several sound issues, mostly for AVM1 fixes #377, #380 and #381
  * [AVM1] fix keyEvent handling
  * add special class for AVM1 TextFields fixes #374
  * [AVM1] implement Key.getAscii fixes #375 and #376
  * implement undocumented tag 253 (apparently needed for obfuscated files)
  * optimize callprperty/callpropvoid with more than one argument
  * properly handle missing FileAttributesTag fixes #372
  * fix event handling during loading of swf files and images
  * replace usage of deprecated type Glib::TimeVal
  * properly read morphfillstyle for FOCAL_RADIAL_GRADIENT
  * fix warning
  * ensure that frames are not declared multiple times when set explicitely
  * implement access to all kinds of DisplayObjects in AVM1
  * [AVM1MovieClipLoader] implement add/removeListener
  * fix possible crash when running AVM1 files fixes #371
  * partially implement flash.globalization.DateTimeFormatter fixes #369
  * [TextField] refresh sizes when calling setTextFormat
  * [DisplayObject] add property "metaData"
  * small performance improvements
  * fixed log text
  * optimize "typeof" opcode
  * inline some methods
  * fix warning
  * check if coercion of arguments can be skipped when executing a SyntheticFunction
  * small performance improvements
  * Implement startDrag/stopDrag for AVM1MovieClip.
  * Add AVM1 methods for getting and setting pan.
  * fix clang-nightly build (again...)
  * new version 0.8.2
  * add support for REGISTER_GETTER_SETTER_RESULTTYPE
  * fix initializing swf files loaded via Loader
  * fix possible crash when handling avm1 events
  * fix jump target handling in preloadFunction
  * fix refcounting when coercing on Vectors
  * handle StartSoundTag as DisplayListTag fixes #364
  * implement AVM1 mouse handling for ASObjects
  * ignore visible flag when rendering to BitmapData
  * implement mouse event handling for AVM1
  * fix avm1 script execution order
  * add stub classes for all filters
  * [DisplayObjectContainer] fix set/deleteVariableByMultiname
  * [ABCVm] fix checkForLocalResult
  * fix mouse click handling
  * work on avm1 support
  * switch to clang-10 for nightly build
  * work on AVM1 support this also fixes #361
  * fix creation of error message
  * several small optimizations
  * fix detection of overridden methods
  * add forgotten patch from last commit
  * rework refcounting in coerce
  * [ABCVm] implement optimization for lessthan opcode
  * optimize builtin methods by setting result type currently only implemented for ByteArray
  * [ABCVm] optimize calling void functions with no arguments
  * fix refcounting for activation objects
  * add more cases where initProperty/setProperty is optimized to setSlot
  * optimize getProperty/setProperty to use getSlot/setSlot if possible
  * fix destruction of DisplayObjects
  * Only require X11 for the NPAPI plugin
  * small performance improvement
  * fix some refcounting issues
  * [ABCVm] optimize convert_b/pushtrue/pushfalse/coerce/construct opcodes
  * [ABCVm] improve checking for local result
  * [ABCVm] optimize constructProp opcode
  * [ABCVm] optimize convert_i and convert_u
  * [ABCVm] add optimization for setSlot, pushNaN and getscopeobject opcodes
  * ensure that names of overridden methods are available before the inherited classes are constructed
  * [ABCVm] disable callFunctionMultiArgs optimization for now
  * [ABCVm] fix increment/decrement optimization
  * [ABCVm] fix findproperty/findpropstrict optimization
  * [ABCVm] optimize alchemy opcodes
  * [ABCVm] optimize increment_i/decrement_i
  * optimize getters and setters by using the type info, when available
  * inline ASObject::destruct()
  * [AVM1] partially implement MovieClipLoader
  * fix warnings
  * fix possible crash
  * [AVM1] implement Key.addListener,Key.removeListener,Key.getCode
  * fix using of actionscript2
  * small performance improvement on arithmetic operations
  * Create Windows NSIS Installer on Tagged Builds
  * rework asAtom, part 5: turn asAtom into a simple union
  * fix ffmpeg warnings
  * enable AVM1 handling for swf version 9
  * Create GitHub Issue Template
  * small performance improvements
  * rework handling of order of operations
  * more refcounting fixes this _really_ fixes #346
  * README: made markdown with badges
  * [AVM1] implement MovieClip.onLoad
  * fix AVM1 string reading
  * adobe seems to accept jpegs with invalid headers, so we do the same
  * Travis CI: Add Ubuntu + Clang Versions
  * more refcounting fixes this fixes #346
  * Another travis ci fix
  * travis ci: use mxe cmake wrapper script
  * next try to fix travis builds...
  * (hopefully) fix travis windows build and remove unneccessary packages
  * more refcounting fixes
  * Fix Clang Casting Error
  * Basic CI with Travis
* Wed May 29 2019 aloisio@gmx.com
- Update to version 0.8.1+git.20190521:
  * fix several refcounting issues
  * [Sound] implement loadCompressedDataFromByteArray fixes #328
  * switch to using lightspark by default for AVM1 files fixes #292 and #339
  * rework asAtom, part 4: reduce size to 8 byte (4 byte on 32bit arch)
  * rework asAtom, part 3: implement seperate types for asAtom
  * rework asAtom, part 2: store method closure seperately
  * rework asAtom, part 1: make type private
  * add checks for interfaces
  * revert accidentally committed stuff
  * [flash.net.ObjectEncoding] implement dynamicPropertyWriter
  * [Textfield] check for number when syncing AVM1 variable
  * [AVM1] ensure that scripts in frame 0 are executed in cloned sprite
  * [Class_base] fix setting of constructIndicator
  * switch to python3
  * [ABCVm] fix skipping of unreachable code
  * don't flush invalidation queue before frame scripts are executed
  * ensure that variable is not bound twice
  * [Array]} fix handling of index 0xFFFFFFFF
  * fix compilation for Windows
  * [DisplayObject] implement getBounds for AVM1
  * [DisplayObject] inherit blendmode from ancestors when rendering
  * [PlaceObject2Tag] ensure that placed objects are not removed
  * [AVM1] fix variable binding
  * [AVM1] fix prototype handling
  * [AVM1] implement _alpha property
  * fix mouse handling for AVM1
  * implement optimized getslot opcode
  * fix focus handling
  * [Graphics] fix beginGradientFill
  * really fix execution order of framescripts
  * fix focus handling
  * [Graphics] fix rendering of objects not on stage
  * fix execution order of framescripts
  * fix the fix for mouse click handling on Sprites...
  * fix iftrue/iffalse optimization
  * reduce excessive copying of GeomTokens
  * fix mouse click handling on sprites
  * [AVM1] fix ActionEnumerate2
  * fix drawing of mixed strokes/fills
  * disable compilation of tightspark by default
  * switch to python3
  * fix mouse input handling
  * [DisplayObjectContainer] fix checkColorTransformForLegacyChildAt
  * [ACTIONRECORD] fix local variables handling for AVM1
  * [ABCVm] fix preloading
  * implement SWF7 action model
  * throw error if argument count is to high
  * [ABCVm] implement some small preload optimizations
  * [Array] speedup isValidMultiname
  * implement swf6 action model
  * avoid infinite loop in checkPropertyException
  * don't expose constructor in describeType
  * implement SampleDataEvent
  * [TextField] fix variable binding
  * [AVM1] fix mouseOut event handling
  * [CairoTokenRenderer] handle ColorTransformation for LineStyles
  * [SimpleButton] fix handling of ColorTransform
  * [AVM1] it seems that Adobe ignores invalid paths in ActionSetProperty
  * [AVM1] another fix for ActionCloneSprite
  * [AVM1] scripts are executed after all DisplayObjects called InitFrame
  * [AVM1] fix hitTest
  * [AVM1] fix ActionCloneSprite
  * [PlaceObject2Tag] ensure name is properly set
  * add forgotten patch to latest commit
  * [ColorTransform] fix applyTransformation
  * [MovieClip] fix purging of placed objects
  * fix rendering of thin lines
  * [AVM1] implement ActionCall
  * [AVM1] implement ActionSetTarget2
  * [AVM1] add Stage class
  * [AVM1] don't overwrite text in bound textfield
  * [AVM1] implement handling for ClipEventLoad and ClipEventEnterFrame
  * fix possible deadlock when handling drag/drop
  * implement SWF5 action model
  * fix MorphShape rendering
  * ensure that AVM1 actions are executed last
  * fix possible deadlock when input listeners are removed during DisplayObjectContainer destruction
  * fix handling of empty JPEGTablesTag
  * implement support for text input
  * implement DefineFontInfoTag
  * implement SWF4 action model
  * don't clean memory too early
  * try to continue when there is no FileAttributes Tag
  * handle first tag correctly
  * better code formatting
  * [MovieClip] ensure gotoAndPlay/gotoAndStop jump to new frame after current function is executed
  * partially implement AVM1 swf3 action model
  * ensure masked objects are invalidated when mask changes
  * optimize shape generation
  * fix several warnings
  * fix sound streaming
  * fix inserting legacy child objects
  * implement sound streaming (SoundStreamHead/SoundStreamHeadBlock tags)
  * add experimental support for swf version 8 and older currently this doesn't do very much, as no actions are implemented, but some animations without user interaction may work. this can be activated by setting environment variable LIGHTSPARK_USE_GNASH=0
  * [RenderThread] apply FrontFace
  * apply ColorTransform when creating rendering tokens for DisplayObjects
  * [SoundChannel] ensure sounds are not played before engine is initialized
  * [Context3D] fix rendering to texture
  * [Stage] fix handling of hidden objects
  * [ABCVm] fix simple getter/setter optimization
  * [CurlDownloader] fix redirected download
  * fix several issues on resampled sounds
  * fix LineStyle/FillStyle creation in SHAPERECORD construction
  * more text rendering issues fixed
  * fix several text rendering issues
  * fix OpenGL not properly detected at runtime on nvidia
  * [TextBloc] fix recreateTextLine
  * implement class ActionScriptVersion fixes #338
  * fix warning
  * fix loading of ppapi plugin
  * [XML] implement undocumented methods notification/setNotification fixes #337
  * optimize simple getters and setters that are only a wrapper around private variables
  * [ABCVm] implement optimization for callpropvoid opcode
  * [ABCVm] optimize iftrue/iffalse opcode
  * implement "not" opcode optimization
  * fix compilation with llvm 7 fixes #336
  * small performance improvement
  * [tiny_string] use avmplus implementation of toupper/tolower
  * [ASString] avoid creation of ASObjects in fromCharCode, if possible
  * implement optimized setproperty for static multinames
  * fix several cmake warnings
  * [SoundMixer] make properties bufferTime and soundTransform static
  * reduce creation of ASObjects
  * [ASObject] avoid creation of ASString objects in nextName
  * optimize equals opcode
  * make llvm dependency optional (disabled by default)
  * implement flash.system.Worker/WorkerDomain fixes #280 and #335
  * more refcounting fixes
  * use libswresample instead of libavresample, if available
  * ensure that symbol 0 from SymbolClassTag takes precedence over non-lazy DoABC tags for execution
  * [Date] make protoype method toString() dynamic
  * [Array] it seems it's allowed to overwrite all prototype methods in Array
  * [ABCContext] set width and height of the swf file from metadata, if available
  * [BuiltinStreamDecoder] set framerate from metadata, if available
  * [DisplayObject] fix deletion of masks
  * [Sound] fix possible crash when loading sound
  * Even more granular memory accounting for Tokens
  * more fixes to reference counting
  * create tokenvector on demand (reduces memory usage)
  * fix compilation on big endian This is not tested, as I don't have access to a big endian machine see https://github.com/lightspark/lightspark/issues/283
  * fix compilation for ppc
  * fix reference counting for synthetic functions created by as3 code
  * disable "add" optimization, as it breaks refcounting
  * [asAtom] avoid creation of ASStrings in isEqual
  * Memory Profiling: Track tokens in separate account
  * fix several refcounting issues
  * Fix MEMORY_USAGE_PROFILING
  * add forgotten patch to last commit
  * [ABCVm] optimize findpropstrict opcode
  * fix refcounting for optimized opcodes
  * [MovieClip] ensure Framescripts are executed after the function calling gotoAndPlay/gotoAndStop/prevFrame/nextFrame is completely executed
  * [CairoTokenRenderer] fix hit test
  * [ABCVm] fix getlex optimization
  * [XML,XMLList] fix hasOwnPrototype
  * [Class_inherit] speedup creation of new instances
  * [ABCVm] optimize getLex when argument can be resolved to a slot of the closure
  * [asAtom] small performance improvement when adding strings
  * [ABCVm] optimize lessequals/greaterequals opcode
  * [asAtom] avoid creating ASStrings for isLess on single char strings
  * fix possible deadlock on multiple concurrent downloads
  * [NetConnection] fix possible crash if download fails
  * ensure that clips are started in correct size on Firefox
  * [ABCVm] fix lookupswitch handling in preloadFunction
  * [ASString] optimize charAt/charCodeAt when iterating over all chars
  * [LoaderInfo] 3rd try to fix sending of init/complete events
  * fix QName to multiname conversion
  * [Array] fix sortOn return value
  * [LoaderInfo] fix sending of init/complete events
  * [TextBlock] fix return value for createTextLine
  * revert fix for loader complete handling
  * fix getLex optimization
  * [DisplayObjectContainer] fix setOnStage
  * [ABCContext] fix handling of const traits in buildTrait
  * [Loader] move "complete" event after the construction of DisplayObject fixes #329
  * fix getProperty optimization
  * [Stage] only request resize if ScaleMode is really changed
  * [ABCVm] implement undocumented opcode 0x5f (finddef)
  * [ABCContext] constant traits without index are initialized to null fixes #327
  * [RootMovieClip] allow framesizes without xmin==0 and ymin==0 fixes #326
  * fix some log output
  * [BuiltinStreamDecoder] fix AAC decoding
  * [SocketPolicyFile] allow \n as last char in downloaded policy file
  * add partial support for rtmfp protocol and ensure NetConnection.connected is set only after the NetConnection.Connect.Success event has been handled
  * [Math] small performance improvement for abs()
  * implement caching of constants created through getlex on static multinames or through arithmetic operations on constants
  * make most prototype methods constant apparently all prototype methods that are not also defined in ASObject are final
  * [ByteArray] fix toString()
  * fix several corner cases for parseInt
  * fix several prototype handling issues
  * [ABCVm] fix instanceOf
  * [Socket] implement endian getter/setter, readBytes and writeBytes fixes #325
  * add stubs for Camera/VideoStreamSettings/H264VideoStreamSettings fixes #323
  * [Date] add toLocaleTimeString with AS3 namespace fixes #324
  * [Number] fix toString() if value is an integer
  * ensure dynamic properties are searched in getLex
  * [JSON] throw exception when parsing empty string
  * [SyntheticFunction] initialize locals to undefined. Apparently it is allowed to access uninitialized local variables fixes #276
  * [SharedObject] return proper values for getRemote and flush
  * [Math] use same precision for mathematical constants as math.h does
  * properly handle slot_traits with slot_id 0
  * prepare release 0.8.1
  * fix caching for callproperty/callpropvoid
  * [Math] small performance improvement for abs
  * [BitmapData] implement perlinNoise
  * partially implement flash.net.Socket
  * check for and remove unreachable code in jump opcode
  * [Array] optimize sortOn
  * optimize performance of returnvalue opcode by avoiding pop of operand from stack wherever possible
  * optimize performance of convert_d opcode by avoiding push/pop of operand and result to/from stack wherever possible
  * [XMLNode] implement NodeName setter
  * [asAtom] fix setFunction
  * fix several chromium plugin issues fixes #321
  * fix possible crash in log output
  * fix possible crash during external call
  * make npapi plugin run on Firefox >= 58
  * speedup newobject opcode handling
  * handle coerce_a opcode when checking for optimization
  * implement caching in optimized static callproperty calls
  * speedup index access to array elements
  * optimize performance of iftrue/iffalse/dup operations by avoiding push/pop of operands and results to/from stack wherever possible
  * optimize performance of callproperty and greaterthan opcodes by avoiding push/pop of operands and results to/from stack wherever possible callproperty is currently only optimized for calls with one argument and static multiname
  * optimize performance of getlex by avoiding push result to stack wherever possible
* Thu May 10 2018 bjorn.lie@gmail.com
- Update to version 0.8.0+git.20180506:
  * optimize performance of branch operators by avoiding push/pop of operands and results to/from stack wherever possible
  * optimize performance of getproperty by avoiding push/pop of operands and results to/from stack wherever possible
  * optimize performance of arithmetic operations by avoiding push/pop of operands and results to/from stack wherever possible
  * fix callproperty caching
  * improve performance of callproperty/callpropvoid/callproplex/getproperty
  * more small performance improvements
  * fix compilation
  * [TextField] fix autoSize handling
  * [CairoRenderContext] implement more BlendModes
  * implement classes flash.display.CapsStyle and flash.display.JointStyle
  * several performance improvements
  * add forgotten patch (fixes #319)
  * [TextField] fix adjusting width and height
  * don't coerce the return value of sort comparison functions This has to be done because otherwise coercing to int may loose the sign of the result (avmplus does the same). fixes #318
  * [XML] fix replace
  * [BitmapData] implement noise
  * force several asAtom methods inline
  * pass asAtom vars by reference to reduce copying
  * more rendering fixes
  * reduce generation of unneccessary ASStrings
  * [DefineEditTextTag] take bounds and leading into account when placing the tag
  * [Vector] fix generator
  * [ABCVm] fix handling of "constructor" property in newClass
  * [DisplayObjectContainer] fix hitTestImpl
  * fix possible crash introduced in last commit
  * fix several rendering issues in Bitmaps and TextFields
  * further reduce generation of primitive ASObjects
  * [Class_base] fix coerceForTemplate
  * speedup handling of one-char-strings
  * [ApplicationDomain] handle templated classes in hasDefinition/ getDefinition
  * [BitmapData] implement hitTest with rectangle
  * [Vector] really fix coercing in concat
  * reduce creation of ASObjects for primitives
  * [ABCVm] fix pushbyte
  * add forgotton patch to previous commit
  * [ABCVm] rework preloadFunction
  * [MorphShape] implement SOLID_FILL morphing
  * [Vector] fix coercing in concat
  * [DisplayObject] implement blend modes ADD and SCREEN
  * [call_context] remove unneccessary reference counting
  * [DisplayObject] implement handling of BlendMode "multiply"
  * [NativeApplication] fix getNativeApplication
  * [SimpleButton] set correct default values for enabled and useHandCursor
  * [Context3D] fix orientation when rendering to texture
  * avoid endless loop on sorting
  * fix stringToQName for template types
  * fix some rounding errors
  * fix mixed rendering of 3D and 2D content
  * fix mingw compilation
  * fix llvm optimizer, part 1
  * fix compilation with clang
  * add command line option to disable rendering removes the need for xvfb for tamarin test suite runs
  * [Context3D] skip rendering if previous frame is not completed
  * [SystemState] fix reference counting in frameListeners fixes https://github.com/lightspark/lightspark/issues/311
  * Fixed C++ scoping issue detected by LLVM Trunk
  * Fixed C++ syntax issue detected by LLVM Trunk
  * Fixed several memory leaks
  * [ThreadPool] catch std exceptions in worker
  * fix handling of multiple embedded fonts with same name
  * [Context3D] implement rendering to texture
  * work on rendertotexture mode for Stage3D
  * work on Stage3D
  * Implemented LINEAR_PCM_LE audio
  * implement DisplacementMapFilterMode and add method stubs to DisplacementMapFilter
  * more work on stage3D
  * [Context3D] handle parameter enableDepthAndStencil in configureBackBuffer
  * [Matrix3D] implement several methods
  * more work on Stage3D implementation
  * [Class_base] don't overwrite borrowed Variables in copyBorrowedTraitsFromSuper
  * [Matrix3D] implement copyRawDataFrom
  * [DefineBitsJPEG3Tag] fix alpha values generation
  * partial implementation of Stage3D support this is a work in progress, it currently only renders some simple examples
  * fix image decoding for DefineBitsLosslessTag
  * remove unused class
  * fix png rendering
  * [FFMpegStreamDecoder] fix decoding with ffmpeg version >= 3.1
  * [XML] fix inScopeNamespaces
  * remove accidentally committed log messages
  * [XML,XMLList] fix hasOwnProperty
  * fix mouse click handling in firefox plugin
  * avoid endless loop on sorting
  * implement Matrix.setTo and Matrix.copyFrom, add stub for Matrix3D.copyRawDataFrom
  * fix sorting with comparison function on Arrays and Vectors
  * switch all remaining classes to asAtom
  * fix serialization
  * switch all Error classes to asAtom
  * avoid creating unneccessary ASObjects on convert_s
  * [Dictionary] switch to asAtom and implement weak keys
  * [flash.system] switch to asAtom
  * fix execution of framescripts
  * [flash.net] switch to asAtom
  * [Date] switch to asAtom
  * partially implement MorphShape rendering does not really morph anything, it more or less just renders the start and end shapes
  * [flash.media] switch to asAtom
  * [flash.filters] switch to asAtom
  * add another case where objects can be cached in findPropStrictCache
  * switch ByteArray and URLStream classes to asAtom
  * [Math] use asAtoms for declared constants
  * properly handle download of adobe signed libraries (*.swz files) We can't decrypt them, so we send an IOErrorEvent when trying to download such a file
  * [XML] add check for empty childrenlist
  * [StyleSheet] add stub for method parseCSS
  * build class for tag on first access
  * [ASFont] implement hasGlyphs for embedded fonts
  * [TextFormat] implement property "display" (not mentioned in spec)
  * [ABCVm] fix caching in getLex
  * fix ArgumentConversionAtom<Ref<T>>
  * [flash.geom.Transform] implement undocumented constructor
  * [flash.text.engine] implement TextElement.replaceText, ContentElement.rawText, FontDescription.isFontCompatible, TextBlock.firstLine, TextBlock.lastLine, TextLine.unjustifiedTextWidth
  * use stage directly instead of going through mainClip (mainClip may be removed from stage)
  * [ASObject] switch to asAtom
  * [flash.geom] switch all classes to asAtom and make them reusable
  * add another test to blacklist that doesn't work on adobe player
  * fix compilation for windows
  * mark BitmapData as initialized when constructed through BitmapTag
  * fix compilation with llvm 5.0 fixes https://github.com/lightspark/lightspark/issues/308
  * fix compilation for Windows
  * [ABCVm] throw correct exception in constructProp
  * [avmplus.System] implement getRunmode
  * [Keyboard] switch to asAtom
  * remove gtk2 dependency
  * [TextField] implement horizontal alignment in <p> tag
  * implement class flash.net.FileFilter
  * make sure root movie clip is availabe in Stage
  * add possibility to switch log levels by pressing ctrl+l (in debug build)
  * several fixes for describeType
  * [RegExp] reset lastIndex if no math is found
  * [Vector] throw correct exception on get/setVariableByMultiname
  * add stubs for methods and classes in package flash.sampler
  * add several tests that fail on adobe player to blacklist
  * implement handling for different swf versions
  * [langref_parser] fix conversion of file path to class package
  * fix several namespace handling bugs in XML/XMLList switch XML/XMLList to asAtom based methods
  * convert all Event classes to asAtom
  * add forgotten patch for eb79070679decb558533c92be6fe75bd86f1d600
  * add several tests that fail on adobe player to blacklist
  * [avmpluFile] implement saving and loading files for standalone version
  * change instance traits into declared traits if they are overwritten in class objects
  * [Array] fix sorting
  * [MovieClip] implement ClipDepth handling
  * [MovieClip] fix execution of first framescript
  * fix refcounting for calling setters
  * forgotten part of last commit
  * fix refcounting for asAtom getters
  * fix llvm detection under Ubuntu
  * getQualifiedClassName: implement handling for T_TEMPLATE also switch several methods to asAtom
  * [RegExp] switch to asAtom
  * [ABCVm] implement callproplex
  * rework reference counting, significantly reduces memory usage
  * Install Pepperflash to the $LIBDIR
  * [CairoTokenRenderer] fix hitTest fixes https://github.com/lightspark/lightspark/issues/299
  * [flash.display] move all classes to asAtom
  * fix reference counting for getVariableByMultiname now every derived version of getVariableByMultiname is expected to deliver the return value so that one ref can be consumed by the caller
  * [asAtom] unify string handling
  * switch all flash.text classes to asAtom
  * allow multinames without namespace in setVariableByMultiname
  * [Number/UInteger] switch to asAtom
- Drop lightspark-link.patch, builds for Tumbleweed and Leap 15.0
  without it, and those are the distros we currently care about.
* Fri Jul 28 2017 mpluskal@suse.com
- Update to version 0.8.0+git.20170723:
  * fix file IO and external call handling in ppapi plugin this avoids several possible deadlocks
  * fix compilation with older ffmpeg versions
  * [flash.media] add stubs for classes SoundMixer and Microphone
  * [flash.text.textengine] add several stub classes and enumerations
  * implement flash.crypto.generateRandomBytes
  * [ABCVm] fix possible crash in coerce
  * [BitmapData] add stub for method "treshold"
  * [DisplayObjectContainer] implement methods "removeChildren" and "getObjectsUnderPoint"
  * [BevelFilter] add several stub properties
  * [flash.geom] add method "setTo" to Rectangle and Point
  * [Sound] handle null urlRequest in constructor
  * [pygil] remove wrong stub classes counting
  * [LocalConnection] partially implement property "domain"
  * [System] add stubs for "pauseForGCIfCollectionImminent" and "gc"
  * [XML] fix namespace for several methods
  * [memorystream] small performance improvements
  * [ASObject] use boost::flat_map instead of std::map as variables map for better performance
  * [ASObject] fix compilation with older boost
  * [ImageDecodingPolicy] fix typo
  * [FFMpegStreamDecoder] fix compilation with ffmpeg 3.0 fixes https://github.com/lightspark/lightspark/issues/281
  * [FFMpegStreamDecoder] really fix compilation with ffmpeg 3.0
  * fix detection of llvm 4.0 fixes https://github.com/lightspark/lightspark/issues/284
  * [RootMovieClip] avoid re-binding classes on every InitFrame
  * improve perfomance by caching the property in callProperty and findPropStrict, if possible
  * reduce the number of dynamic_casts
  * use unsigned integer in loops
  * [SharedObject] add missing incRef
  * [ABCVm] fix callPropertyCache
  * [ABCVm] cache type in multiname
  * [TextField] only request invalidation if really neccessary
  * [ABCVm] remove callPropertyCache, it doesn't work correctly and doesn't really improve perfomance
  * [ABCVm] small speedup for getMultiname()
  * [Class_base] performance improvement for isSubClass()
  * add new builtin string "length"
  * [ASObject] only search in declared variables if multiname doesn't contain the public namespace
  * [Array] switch to flat_map
  * [ABCVm] throw correct errors in checkfilter
  * [Matrix3D] add some method stubs
  * [DisplayObject] add some property stubs
  * switch to using a flat_multimap for variables. namespaces in multinames are not sorted anymore.
  * [Array] fix some corner cases when handling index UINT32_MAX
  * [memorystream] cache the u30/s24 codes before executing a function the first time
  * [TagFactory] don't throw exception if tag is longer as expected (Adobe seems to allow this, too)
  * [ThreadPool] increase number of threads this leads to less stuttering when playing multiple sounds
  * set emulated version to current adobe version
  * [SyntheticFunction] add call to ABCVm::preloadFunction
  * enale building of ppapi plugin by default
  * [ASObject] handle declared properties in JSON stringify
  * [ASObject] more fixes for JSON.stringify
  * [ABCVm] use function pointer array instead of switch in executeFunction
  * [IFunction] fix prototype constructor
  * [Number] add toLocaleString and make several properties not enumerable
  * return exit code 1 if exit was caused by uncaught exception
  * [tests] switch to the github adobe avmplus repository as base for the tamarin test suite
  * [Global] make all builtin classes constant traits
  * [Array] implement insertAt() and removeAt()
  * [Vector] implement insertAt() and removeAt()
  * fix test output
  * rework blacklist for tests not working on adobe (not yet complete)
  * [avmplus] implement System.canonicalizeNumber
  * [SharedObject] add stub method setProperty()
  * remove more dynamic_casts
  * [ArgumentConversion] handle Undefined in toConcrete()
  * [ABCVm] fix sxi1 opcode implementation
  * [Array] small performance improvement in isValidMultiname()
  * [ApplicationDomain/avmplus.Domain] fix DomainMemory handling
  * [SyntheticFunction] fix needsRest()
  * [ASFont] add stub for hasGlyphs()
  * [DisplayObjectContainer] fix deleteLegacyChildAt
  * [avmplusDomain] implement loadBytes()
  * reduce number of AsyncDrawJobs by ensuring a DisplayObject is only rendered once until it changes again
  * [InputThread] add null-checks to results of getMouseTarget
  * [ABCVm] implement opcode hasnext (0x1f)
  * remove more dynamic_casts
  * [SystemState] avoid creating AsyncDrawJob if DisplayObject is unchanged
  * add test to blacklist that doesn't work on Adobe
  * [BitmapData] add stub for method "merge"
  * [ABCVm] remove unneeded argument from abc_function
  * implement alpha support for pngs and images with palette
  * [ABCVm] implement opcode 0x43 (callMethod)
  * [DisplayObject] implement ColorTransform handling
  * implement stroke handling in Shapes
  * introduce class asAtom as wrapper around ASObject This allows operations on primitives without reference counting. TODO: There are only a few builtin methods currently converted to this wrapper, see usage of ASFUNCTION_ATOM vs ASFUNCTION
  * fix warning
  * conversion to asAtom, second part calling of functions is now handled in asAtom to avoid creating of new function objects every time the function is executed
  * conversion to asAtom, third part Vector class uses vector of asAtom as underlying data structure
  * move several #includes from .h to .cpp
  * [CairoTokenRenderer] only draw strokes if necessary
  * set results of arithmetic operations on asAtoms as (U)Integers, if possible
  * [Math] fix several corner cases
  * [variables_map] switch to unordered_map as basic datastructure
  * conversion to asAtom, fourth part - all ASString methods use asAtom - ASFUNCTION_ATOM now has additional parameter "sys"
  * [Array] switch to unordered_map to store array elements
  * rework function calling to only count references if neccessary
  * fix compilation for Windows fixes issues #270 and #288 the npapi/ppapi plugins compile but are not tested
  * fix compilation on older stdlib
  * [Array] use std::vector for small arrays (up to 65536 elements) and unordered_map for large arrays
  * [asAtom] make most methods inline
  * [Vector] fix forEach
  * [multiname] small performance improvements
  * add more subtypes for dynamic casts
  * [ExternalInterface] switch to asAtom
  * [SecurityManager] allow to call https URLs even if the main URL is http
  * fix compilation on windows
  * fix compilation in profiling mode fixes https://github.com/lightspark/lightspark/issues/291
  * make NPAPI plugin windowless
  * fix minGW compilation
  * prepare release 0.8
  * bump version number
  * Now Cmake supports LLVM up to 4.0
  * add several missing tags in describeType
  * [ApplicationDomain] fix hasDefinition/getDefinition
  * Add NullVideoDecoder::switchCodec
  * fix ArgumentConversionAtom
  * don't throw if setting a dynamic variable with not-empty namespace
  * [ASString] fix localeCompare
  * [method_info] switch to asAtom for getConstant/getOptional
  * [Integer] switch to asAtom
  * [asAtom] add support for strings with a stringID, reduces the need to create ASString objects in some cases
  * [pygil] implement detection of setVariableAtomByQName
  * add two tests to blacklist that don't work on Adobe
* Thu Mar  2 2017 jengelh@inai.de
- Update description
* Thu Feb 23 2017 mpluskal@suse.com
- Update to version 0.7.2+git.20170107:
  * [ppapi] implement keyboard and mouse event handling
  * [ppapi] implement downloading of additional files
  * directly include shaders into sourcecode to avoid filesystem access which is not allowed in ppapi sandbox
  * [Config] fix loading config from ppapi plugin ppapi doesn't allow direct filesystem access so we just ignore the errors reported when trying to load config file
  * [ppapi] implement separate file cache for ppapi plugin. Now the ppapi plugin runs in sandboxed mode with some limitations: - It doesn't detect system fonts properly as cairo tries to read fontconfig files which is not allowed from sandbox. - Sound output doesn't work yet, as sdl_audio initialization crashes when done inside sandbox.
  * [FFMpegStreamDecoder] fix possible crash when probing input format
  * [ppapi] implement sound support
  * [SoundChannel] implement volume handling
  * [ppapi] implement font rendering
  * [SoundTransform] initialize volume/pan to default values
- Add _service
- Add lightspark-link.patch
* Tue Sep 22 2015 olaf@aepfle.de
- Use pkgconfig for ffmpeg BuildRequires
* Thu May 30 2013 mhrusecky@suse.cz
- fixed build with new llvm: llvm-3.3.patch
* Mon May  6 2013 reddwarf@opensuse.org
- Update to 0.7.2
  * Improved image support: alpha in palettes, abbreviated JPEGs
  * Improved embedded font parsing and text positioning
  * Open links in a browser (plugin only)
  * BitmapData improvements
  * Fixed many crashes
- Remove lightspark-0.7.0-no_glu.patch. Applied upstream.
* Thu Dec 27 2012 reddwarf@opensuse.org
- Update to 0.7.1
  * Fixes for YouTube
  * Support keyboard press and release events
  * Support mouse wheel events and other mouse event improvements
  * Support LLVM 3.2
  * Implemented hit testing of DisplayObjects
  * Parse JPEG images embedded in DefineBits tags
  * Parse RGB15 and paletted images in DefineBitsLossless tags
  * Improved XML support
- Remove lightspark-0.7.0-llvm32.patch, applied upstream.
* Fri Nov 30 2012 reddwarf@opensuse.org
- Add lightspark-0.7.0-llvm32.patch to fix build with LLVM 3.2
* Wed Oct 31 2012 reddwarf@opensuse.org
- Update to 0.7.0
  * Support LZMA compressed SWFs [Requires liblzma]
  * Improved BitmapData support
  * Improved ActionScript compatibility
  * Improved virtual machine performance and memory consumption
  * Improved XML support
  * Experimental support for bytecode optimization at runtime
  * Improved ExternalInterface (browser integration) support
  * Improved performance of JPEG loading
  * Support for XMLSocket
  * Completely redesigned and improved masking support
- Take minimum version of pkgconfig(libxml++-2.6) and llvm-devel
  from CMakeLists.txt and specify them in the BuildRequires
- Add pkgconfig(liblzma), pkgconfig(gl) and pkgconfig(zlib) BuildRequires
- Remove pkgconfig(gobject-2.0) BuildRequire
- Add lightspark-0.7.0-no_glu.patch and remove explicit glu dependency
* Fri Sep 21 2012 idonmez@suse.com
- Add explicit glu dependency
* Fri Jun 22 2012 reddwarf@opensuse.org
- Update to 0.6.0.1
  * Enable RTMP support by default, requires librtmp
  * Fixed support for IEventDispatcher implementation pattern
  * Improved serialization robustness
  * Improved matrix handling
  * Implement string and namespace pooling to reduce memory consumption
  * Proper support for private namespaces
  * Improved support for fonts
  * Support LLVM 3.1
  * Fix full volume issue when PulseAudio flat volumes are enabled
  * Initial support for AIR desktop applications
  * Support for www.bbc.co.uk video player
- Remove lightspark-0.5.7-llvm_31.patch and
  lightspark-0.5.7-ffmpeg_011.patch, applied upstream
- Optionally support RTMP
* Wed Jun  6 2012 reddwarf@opensuse.org
- Fix ffmpeg 0.11 patch, now upstreamed
* Mon May 28 2012 reddwarf@opensuse.org
- Fix build with ffmpeg 0.11
* Thu May 17 2012 reddwarf@opensuse.org
- Update to 0.5.7
* Tue Mar 27 2012 reddwarf@opensuse.org
- Don't remove rpath
* Thu Mar 22 2012 reddwarf@opensuse.org
- Update to 0.5.5
* Sat Dec 11 2010 reddwarf@opensuse.org
- Initial package
